summaryrefslogtreecommitdiff
path: root/src/include/taler_signatures.h
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2015-05-16 14:15:34 +0200
committerChristian Grothoff <christian@grothoff.org>2015-05-16 14:15:34 +0200
commitf4a59d1cccd058b3180ea23ed9fdea69cb2129b8 (patch)
treead732a3b92fcd74f5c1295ceee5c06e3a63b3206 /src/include/taler_signatures.h
parentd080e59e272e307b9ebc267f2c4dd2941cd79436 (diff)
downloadexchange-f4a59d1cccd058b3180ea23ed9fdea69cb2129b8.tar.gz
exchange-f4a59d1cccd058b3180ea23ed9fdea69cb2129b8.tar.bz2
exchange-f4a59d1cccd058b3180ea23ed9fdea69cb2129b8.zip
eliminating ECDSA, replacing with EdDSA-ECDHE-combo in transfer protocol
Diffstat (limited to 'src/include/taler_signatures.h')
-rw-r--r--src/include/taler_signatures.h26
1 files changed, 8 insertions, 18 deletions
diff --git a/src/include/taler_signatures.h b/src/include/taler_signatures.h
index de6dbfc24..bc34c32e9 100644
--- a/src/include/taler_signatures.h
+++ b/src/include/taler_signatures.h
@@ -123,16 +123,6 @@
/**
- * ECDSA test signature.
- */
-#define TALER_SIGNATURE_CLIENT_TEST_ECDSA 1300
-
-/**
- * ECDSA test signature.
- */
-#define TALER_SIGNATURE_MINT_TEST_ECDSA 1301
-
-/**
* EdDSA test signature.
*/
#define TALER_SIGNATURE_CLIENT_TEST_EDDSA 1302
@@ -207,7 +197,7 @@ struct TALER_DepositRequestPS
{
/**
* Purpose must be #TALER_SIGNATURE_WALLET_COIN_DEPOSIT.
* Used for an ECDSA signature with the `union TALER_CoinSpendPublicKeyP`.
*/
struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
@@ -283,9 +273,9 @@ struct TALER_DepositRequestPS
/**
* The coin's public key. This is the value that must have been
* signed (blindly) by the Mint. The deposit request is to be
- * signed by the corresponding private key (using ECDSA).
+ * signed by the corresponding private key (using EdDSA).
*/
- union TALER_CoinSpendPublicKeyP coin_pub;
+ struct TALER_CoinSpendPublicKeyP coin_pub;
};
@@ -341,9 +331,9 @@ struct TALER_DepositConfirmationPS
/**
* The coin's public key. This is the value that must have been
* signed (blindly) by the Mint. The deposit request is to be
- * signed by the corresponding private key (using ECDSA).
+ * signed by the corresponding private key (using EdDSA).
*/
- union TALER_CoinSpendPublicKeyP coin_pub;
+ struct TALER_CoinSpendPublicKeyP coin_pub;
/**
* The Merchant's public key. Allows the merchant to later refund
@@ -363,7 +353,7 @@ struct TALER_RefreshMeltCoinAffirmationPS
{
/**
* Purpose is #TALER_SIGNATURE_WALLET_COIN_MELT.
* Used for an ECDSA signature with the `union TALER_CoinSpendPublicKeyP`.
*/
struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
@@ -396,9 +386,9 @@ struct TALER_RefreshMeltCoinAffirmationPS
/**
* The coin's public key. This is the value that must have been
* signed (blindly) by the Mint. The deposit request is to be
- * signed by the corresponding private key (using ECDSA).
+ * signed by the corresponding private key (using EdDSA).
*/
- union TALER_CoinSpendPublicKeyP coin_pub;
+ struct TALER_CoinSpendPublicKeyP coin_pub;
};
@@ -207,7 +197,7 @@ struct TALER_DepositRequestPS
/**
* Purpose must be #TALER_SIGNATURE_WALLET_COIN_DEPOSIT.
- * Used for an ECDSA signature with the `union TALER_CoinSpendPublicKeyP`.
+ * Used for an EdDSA signature with the `struct TALER_CoinSpendPublicKeyP`.
*/
struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
@@ -363,7 +353,7 @@ struct TALER_RefreshMeltCoinAffirmationPS
/**
* Purpose is #TALER_SIGNATURE_WALLET_COIN_MELT.
- * Used for an ECDSA signature with the `union TALER_CoinSpendPublicKeyP`.
+ * Used for an EdDSA signature with the `struct TALER_CoinSpendPublicKeyP`.
*/
struct GNUNET_CRYPTO_EccSignaturePurpose purpose;